@@ -12,7 +12,7 @@ class RequiredSettingMissing(Exception):
         super(RequiredSettingMissing, self).__init__(msg)
 
 
-def get_env(key, default=None, coerce=lambda x: x, required=False):
+def _get_env(key, default=None, coerce=lambda x: x, required=False):
     """Return env var coerced into a type other than string.
 
     This function extends the standard os.getenv function to enable
@@ -23,21 +23,15 @@ def get_env(key, default=None, coerce=lambda x: x, required=False):
         key: string, the name of the env var to look up
 
     Kwargs:
-        default: the default value to return if the env var does not
-            exist and required is False
+        default: the default value to return if the env var does not exist
         coerce: a function that is used to coerce the value returned into
-            another type - e.g. coerce=lambda x: int(x) would convert a
-            string into an integer.
-        required: bool, if the env var does not exist and this is True, then
-            a RequiredSettingMissing error is raised. NB you cannot set
-            required to True and pass in a default value.
+            another type
+        required: bool, if True, then a RequiredSettingMissing error is raised
+            if the env var does not exist.
 
     Returns the env var, passed through the coerce function
 
     """
-    assert not (default and required), (
-        u"You cannot pass required=True and a default value to get_env."
-    )
     try:
         return coerce(os.environ[key])
     except KeyError:
@@ -57,69 +51,75 @@ coerce_datetime = lambda x: parser.parse(x)
 coerce_date = lambda x: parser.parse(x).date()
 
 
-def _get_env(key, *default, **kwargs):
+def get_env(key, *default, **kwargs):
     """
-    Unpack default, required and coerce kwargs.
+    Return env var.
 
-    This is a helper function used to unpack the type-specific get_FOO
-    functions' args. Each individual function has one mandatory arg (key),
-    and an optional arg (*default) - this is a hack. If a default is not
-    passed in, then the env var is assumed to be required.
+    This is the parent function of all other get_foo functions,
+    and is responsible for unpacking args/kwargs into the values
+    that _get_env expects (it is the root function that actually
+    interacts with environ).
 
-    This function should never be called directly.
+    Args:
+        key: string, the env var name to look up.
+        default: (optional) the value to use if the env var does not
+            exist. If this value is not supplied, then the env var is
+            considered to be required, and a RequiredSettingMissing
+            error will be raised if it does not exist.
 
-        # 'foo' is a mandatory env var
-        >>> get_int('foo')
+    Kwargs:
+        coerce: a func that may be supplied to coerce the value into
+            something else. This is used by the default get_foo functions
+            to cast strings to builtin types, but could be a function that
+            returns a custom class.
 
-        # 'foo' is optional
-        >>> get_int('foo', 123)
+    Returns the env var, coerced if required, and a default if supplied.
 
     """
     assert len(default) in (0, 1), "Too many args supplied."
-    assert 'coerce' in kwargs, "Kwargs must include 'coerce' function arg."
-    if len(default) == 0:
-        return get_env(key, coerce=kwargs['coerce'], required=True)
-    else:
-        return get_env(key, default=default[0], coerce=kwargs['coerce'])
+    func = kwargs.get('coerce', lambda x: x)
+    required = (len(default) == 0)
+    default = default[0] if not required else None
+    return _get_env(key, default=default, coerce=func, required=required)
 
 
 def get_bool(key, *default):
     """Return env var cast as boolean."""
-    return _get_env(key, *default, coerce=coerce_bool)
+    return get_env(key, *default, coerce=coerce_bool)
 
 
 def get_int(key, *default):
     """Return env var cast as integer."""
-    return _get_env(key, *default, coerce=coerce_int)
+    return get_env(key, *default, coerce=coerce_int)
 
 
 def get_float(key, *default):
     """Return env var cast as float."""
-    return _get_env(key, *default, coerce=coerce_float)
+    return get_env(key, *default, coerce=coerce_float)
 
 
 def get_decimal(key, *default):
     """Return env var cast as Decimal."""
-    return _get_env(key, *default, coerce=coerce_decimal)
+    return get_env(key, *default, coerce=coerce_decimal)
 
 
 def get_list(key, *default, **kwargs):
     """Return env var as a list."""
     separator = kwargs.get('separator', ' ')
     func = lambda x: x.split(separator)
-    return _get_env(key, *default, coerce=func)
+    return get_env(key, *default, coerce=func)
 
 
 def get_dict(key, *default):
     """Return env var as a dict."""
-    return _get_env(key, *default, coerce=coerce_dict)
+    return get_env(key, *default, coerce=coerce_dict)
 
 
 def get_date(key, *default):
     """Return env var as a date."""
-    return _get_env(key, *default, coerce=coerce_date)
+    return get_env(key, *default, coerce=coerce_date)
 
 
 def get_datetime(key, *default):
     """Return env var as a datetime."""
-    return _get_env(key, *default, coerce=coerce_datetime)
+    return get_env(key, *default, coerce=coerce_datetime)
